body {
    padding: 10px;
    border-radius: 5px;
    border-color: #0a0a0a;
    border-width: 2px;
    font-family: arial;
    line-height: 1;
}

#main {
    background-color: #fafafa;
    border-width: 1px;
    border-color: #a0a0a0;
    border-style: solid;
    box-shadow: 5px 5px 6px #888;
    padding-top: 10px;
    padding-bottom: 10px;
}

.h1 {
    font-size: 20px;
}

.actions {
    color: black;
    font-size: 12px;
    font-weight: bold;
    padding-right: 5px;
    vertical-align: middle;
}

.test_running, .suite_running, .module_running,
.test_passed, .suite_passed, .module_passed,
.test_skipped, .suite_skipped, .module_skipped {
    border-left-width: 10px;
    border-left-style: solid;
}

.test_failed, .suite_failed, .module_failed {
    border-left-color: red;
}

.test_skipped, .suite_skipped, .module_skipped {
    border-left-color: orange;
}

.test_passed, .suite_passed, .module_passed {
    border-left-color: green;
}

.test_running, .suite_running, .module_running {
    border-left-color: transparent;
}

.module_name, .suite_name, .test_name {
   border-left-width: 10px;
    border-left-style: solid;
    padding-left: 5px;
    padding-top: 4px;
    padding-bottom: 4px;
}

@-moz-document url-prefix() {
    /* firefox only. The indicator color bars hide the hr so they should be shorter */
    .module_name, .suite_name, .test_name {
        padding-bottom: 3px;
    }
}

.module_name {
    margin-left: 5px;
}

.suite_name {
    margin-left: 30px;
}

.test_name {
    margin-left: 55px;
}

.module-row, .suite-row, .test-row {
    margin-top: 5px;
    margin-bottom: 5px;
    margin-right: 10px;
    margin-left: 10px;
}

hr.white-line {
    height: 1px;
    background-color: white;
    border: 0;
    margin: 0;
}

hr.module-separator {
    height: 1px;
    border: 0;
    background-color: #a0a0a0;
    margin-top: 20px;
    margin-bottom: 20px;
}

.legend {
    font-size: 12px;
    margin-top: 10px;
}

.test_running {
    font-style: italic;
    color: #808080;
}

.right-arrow {
    display: inline-block;
    width: 0px;
    height: 0px;
    border-style: solid;
    border-width: 5px 0 5px 10px;
    border-color: transparent transparent transparent #878787;
}

.down-arrow {
    display: inline-block;
    width: 0px;
    height: 0px;
    border-style: solid;
    border-width: 10px 5px 0 5px;
    border-color: #878787 transparent transparent transparent;
}

.code_link, .desc_link, .log_link {
    text-decoration: none;
    color: #c0c0c0;
}

.code_link[href], .desc_link[href], .log_link[href] {
    color: black;
    text-decoration: underline;
}

.description {
    margin-left: 150px;
    border: 1px solid silver;
    width: 40%;
    padding: 10px;
    margin-top: 5px;
}

#running-spinner {
    width: 20px;
    height: 20px;
    display: inline-block;
}